@@ -3,13 +3,14 @@ Main interface for shield service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.shield import (
+    from mypy_boto3_shield import (
         Client,
         ListAttacksPaginator,
         ListProtectionsPaginator,
         ShieldClient,
-        )
+    )
 
     session = boto3.Session()
 
@@ -18,6 +19,7 @@ Usage::
 
     list_attacks_paginator: ListAttacksPaginator = client.get_paginator("list_attacks")
     list_protections_paginator: ListProtectionsPaginator = client.get_paginator("list_protections")
+    ```
 """
 from mypy_boto3_shield.client import ShieldClient, ShieldClient as Client
 from mypy_boto3_shield.paginator import ListAttacksPaginator, ListProtectionsPaginator
