@@ -3,8 +3,11 @@ Main interface for shield service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.shield import (
+
+    from mypy_boto3_shield import ShieldClient
+    from mypy_boto3_shield import (
         ListAttacksPaginator,
         ListProtectionsPaginator,
     )
@@ -13,6 +16,7 @@ Usage::
 
     list_attacks_paginator: ListAttacksPaginator = client.get_paginator("list_attacks")
     list_protections_paginator: ListProtectionsPaginator = client.get_paginator("list_protections")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from typing import Iterator, List, TYPE_CHECKING
@@ -30,7 +34,7 @@ __all__ = ("ListAttacksPaginator", "ListProtectionsPaginator")
 
 class ListAttacksPaginator(Boto3Paginator):
     """
-    [Paginator.ListAttacks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/shield.html#Shield.Paginator.ListAttacks)
+    [Paginator.ListAttacks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/shield.html#Shield.Paginator.ListAttacks)
     """
 
     def paginate(
@@ -41,18 +45,18 @@ class ListAttacksPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListAttacksResponseTypeDef]:
         """
-        [ListAttacks.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/shield.html#Shield.Paginator.ListAttacks.paginate)
+        [ListAttacks.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/shield.html#Shield.Paginator.ListAttacks.paginate)
         """
 
 
 class ListProtectionsPaginator(Boto3Paginator):
     """
-    [Paginator.ListProtections documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/shield.html#Shield.Paginator.ListProtections)
+    [Paginator.ListProtections documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/shield.html#Shield.Paginator.ListProtections)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListProtectionsResponseTypeDef]:
         """
-        [ListProtections.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/shield.html#Shield.Paginator.ListProtections.paginate)
+        [ListProtections.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/shield.html#Shield.Paginator.ListProtections.paginate)
         """
