@@ -3,9 +3,11 @@ Main interface for shield service type definitions.
 
 Usage::
 
-    from mypy_boto3.shield.type_defs import CreateProtectionResponseTypeDef
+    ```python
+    from mypy_boto3_shield.type_defs import AttackDetailTypeDef
 
-    data: CreateProtectionResponseTypeDef = {...}
+    data: AttackDetailTypeDef = {...}
+    ```
 """
 from datetime import datetime
 import sys
@@ -22,38 +24,47 @@ else:
 
 
 __all__ = (
-    "CreateProtectionResponseTypeDef",
-    "ContributorTypeDef",
-    "AttackPropertyTypeDef",
-    "MitigationTypeDef",
-    "SummarizedCounterTypeDef",
-    "SummarizedAttackVectorTypeDef",
-    "SubResourceSummaryTypeDef",
     "AttackDetailTypeDef",
+    "AttackPropertyTypeDef",
+    "AttackSummaryTypeDef",
+    "AttackVectorDescriptionTypeDef",
+    "ContributorTypeDef",
+    "EmergencyContactTypeDef",
+    "LimitTypeDef",
+    "MitigationTypeDef",
+    "ProtectionTypeDef",
+    "SubResourceSummaryTypeDef",
+    "SubscriptionTypeDef",
+    "SummarizedAttackVectorTypeDef",
+    "SummarizedCounterTypeDef",
+    "CreateProtectionResponseTypeDef",
     "DescribeAttackResponseTypeDef",
     "DescribeDRTAccessResponseTypeDef",
-    "EmergencyContactTypeDef",
     "DescribeEmergencyContactSettingsResponseTypeDef",
-    "ProtectionTypeDef",
     "DescribeProtectionResponseTypeDef",
-    "LimitTypeDef",
-    "SubscriptionTypeDef",
     "DescribeSubscriptionResponseTypeDef",
     "GetSubscriptionStateResponseTypeDef",
-    "AttackVectorDescriptionTypeDef",
-    "AttackSummaryTypeDef",
     "ListAttacksResponseTypeDef",
     "ListProtectionsResponseTypeDef",
     "PaginatorConfigTypeDef",
     "TimeRangeTypeDef",
 )
 
-CreateProtectionResponseTypeDef = TypedDict(
-    "CreateProtectionResponseTypeDef", {"ProtectionId": str}, total=False
+AttackDetailTypeDef = TypedDict(
+    "AttackDetailTypeDef",
+    {
+        "AttackId": str,
+        "ResourceArn": str,
+        "SubResources": List["SubResourceSummaryTypeDef"],
+        "StartTime": datetime,
+        "EndTime": datetime,
+        "AttackCounters": List["SummarizedCounterTypeDef"],
+        "AttackProperties": List["AttackPropertyTypeDef"],
+        "Mitigations": List["MitigationTypeDef"],
+    },
+    total=False,
 )
 
-ContributorTypeDef = TypedDict("ContributorTypeDef", {"Name": str, "Value": int}, total=False)
-
 AttackPropertyTypeDef = TypedDict(
     "AttackPropertyTypeDef",
     {
@@ -68,18 +79,72 @@ AttackPropertyTypeDef = TypedDict(
             "WORDPRESS_PINGBACK_REFLECTOR",
             "WORDPRESS_PINGBACK_SOURCE",
         ],
-        "TopContributors": List[ContributorTypeDef],
+        "TopContributors": List["ContributorTypeDef"],
         "Unit": Literal["BITS", "BYTES", "PACKETS", "REQUESTS"],
         "Total": int,
     },
     total=False,
 )
 
+AttackSummaryTypeDef = TypedDict(
+    "AttackSummaryTypeDef",
+    {
+        "AttackId": str,
+        "ResourceArn": str,
+        "StartTime": datetime,
+        "EndTime": datetime,
+        "AttackVectors": List["AttackVectorDescriptionTypeDef"],
+    },
+    total=False,
+)
+
+AttackVectorDescriptionTypeDef = TypedDict("AttackVectorDescriptionTypeDef", {"VectorType": str})
+
+ContributorTypeDef = TypedDict("ContributorTypeDef", {"Name": str, "Value": int}, total=False)
+
+_RequiredEmergencyContactTypeDef = TypedDict(
+    "_RequiredEmergencyContactTypeDef", {"EmailAddress": str}
+)
+_OptionalEmergencyContactTypeDef = TypedDict(
+    "_OptionalEmergencyContactTypeDef", {"PhoneNumber": str, "ContactNotes": str}, total=False
+)
+
+
+class EmergencyContactTypeDef(_RequiredEmergencyContactTypeDef, _OptionalEmergencyContactTypeDef):
+    pass
+
+
+LimitTypeDef = TypedDict("LimitTypeDef", {"Type": str, "Max": int}, total=False)
+
 MitigationTypeDef = TypedDict("MitigationTypeDef", {"MitigationName": str}, total=False)
 
-SummarizedCounterTypeDef = TypedDict(
-    "SummarizedCounterTypeDef",
-    {"Name": str, "Max": float, "Average": float, "Sum": float, "N": int, "Unit": str},
+ProtectionTypeDef = TypedDict(
+    "ProtectionTypeDef",
+    {"Id": str, "Name": str, "ResourceArn": str, "HealthCheckIds": List[str]},
+    total=False,
+)
+
+SubResourceSummaryTypeDef = TypedDict(
+    "SubResourceSummaryTypeDef",
+    {
+        "Type": Literal["IP", "URL"],
+        "Id": str,
+        "AttackVectors": List["SummarizedAttackVectorTypeDef"],
+        "Counters": List["SummarizedCounterTypeDef"],
+    },
+    total=False,
+)
+
+SubscriptionTypeDef = TypedDict(
+    "SubscriptionTypeDef",
+    {
+        "StartTime": datetime,
+        "EndTime": datetime,
+        "TimeCommitmentInSeconds": int,
+        "AutoRenew": Literal["ENABLED", "DISABLED"],
+        "Limits": List["LimitTypeDef"],
+        "ProactiveEngagementStatus": Literal["ENABLED", "DISABLED", "PENDING"],
+    },
     total=False,
 )
 
@@ -88,7 +153,7 @@ _RequiredSummarizedAttackVectorTypeDef = TypedDict(
 )
 _OptionalSummarizedAttackVectorTypeDef = TypedDict(
     "_OptionalSummarizedAttackVectorTypeDef",
-    {"VectorCounters": List[SummarizedCounterTypeDef]},
+    {"VectorCounters": List["SummarizedCounterTypeDef"]},
     total=False,
 )
 
@@ -99,103 +164,51 @@ class SummarizedAttackVectorTypeDef(
     pass
 
 
-SubResourceSummaryTypeDef = TypedDict(
-    "SubResourceSummaryTypeDef",
-    {
-        "Type": Literal["IP", "URL"],
-        "Id": str,
-        "AttackVectors": List[SummarizedAttackVectorTypeDef],
-        "Counters": List[SummarizedCounterTypeDef],
-    },
+SummarizedCounterTypeDef = TypedDict(
+    "SummarizedCounterTypeDef",
+    {"Name": str, "Max": float, "Average": float, "Sum": float, "N": int, "Unit": str},
     total=False,
 )
 
-AttackDetailTypeDef = TypedDict(
-    "AttackDetailTypeDef",
-    {
-        "AttackId": str,
-        "ResourceArn": str,
-        "SubResources": List[SubResourceSummaryTypeDef],
-        "StartTime": datetime,
-        "EndTime": datetime,
-        "AttackCounters": List[SummarizedCounterTypeDef],
-        "AttackProperties": List[AttackPropertyTypeDef],
-        "Mitigations": List[MitigationTypeDef],
-    },
-    total=False,
+CreateProtectionResponseTypeDef = TypedDict(
+    "CreateProtectionResponseTypeDef", {"ProtectionId": str}, total=False
 )
 
 DescribeAttackResponseTypeDef = TypedDict(
-    "DescribeAttackResponseTypeDef", {"Attack": AttackDetailTypeDef}, total=False
+    "DescribeAttackResponseTypeDef", {"Attack": "AttackDetailTypeDef"}, total=False
 )
 
 DescribeDRTAccessResponseTypeDef = TypedDict(
     "DescribeDRTAccessResponseTypeDef", {"RoleArn": str, "LogBucketList": List[str]}, total=False
 )
 
-EmergencyContactTypeDef = TypedDict("EmergencyContactTypeDef", {"EmailAddress": str})
-
 DescribeEmergencyContactSettingsResponseTypeDef = TypedDict(
     "DescribeEmergencyContactSettingsResponseTypeDef",
-    {"EmergencyContactList": List[EmergencyContactTypeDef]},
-    total=False,
-)
-
-ProtectionTypeDef = TypedDict(
-    "ProtectionTypeDef",
-    {"Id": str, "Name": str, "ResourceArn": str, "HealthCheckIds": List[str]},
+    {"EmergencyContactList": List["EmergencyContactTypeDef"]},
     total=False,
 )
 
 DescribeProtectionResponseTypeDef = TypedDict(
-    "DescribeProtectionResponseTypeDef", {"Protection": ProtectionTypeDef}, total=False
-)
-
-LimitTypeDef = TypedDict("LimitTypeDef", {"Type": str, "Max": int}, total=False)
-
-SubscriptionTypeDef = TypedDict(
-    "SubscriptionTypeDef",
-    {
-        "StartTime": datetime,
-        "EndTime": datetime,
-        "TimeCommitmentInSeconds": int,
-        "AutoRenew": Literal["ENABLED", "DISABLED"],
-        "Limits": List[LimitTypeDef],
-    },
-    total=False,
+    "DescribeProtectionResponseTypeDef", {"Protection": "ProtectionTypeDef"}, total=False
 )
 
 DescribeSubscriptionResponseTypeDef = TypedDict(
-    "DescribeSubscriptionResponseTypeDef", {"Subscription": SubscriptionTypeDef}, total=False
+    "DescribeSubscriptionResponseTypeDef", {"Subscription": "SubscriptionTypeDef"}, total=False
 )
 
 GetSubscriptionStateResponseTypeDef = TypedDict(
     "GetSubscriptionStateResponseTypeDef", {"SubscriptionState": Literal["ACTIVE", "INACTIVE"]}
 )
 
-AttackVectorDescriptionTypeDef = TypedDict("AttackVectorDescriptionTypeDef", {"VectorType": str})
-
-AttackSummaryTypeDef = TypedDict(
-    "AttackSummaryTypeDef",
-    {
-        "AttackId": str,
-        "ResourceArn": str,
-        "StartTime": datetime,
-        "EndTime": datetime,
-        "AttackVectors": List[AttackVectorDescriptionTypeDef],
-    },
-    total=False,
-)
-
 ListAttacksResponseTypeDef = TypedDict(
     "ListAttacksResponseTypeDef",
-    {"AttackSummaries": List[AttackSummaryTypeDef], "NextToken": str},
+    {"AttackSummaries": List["AttackSummaryTypeDef"], "NextToken": str},
     total=False,
 )
 
 ListProtectionsResponseTypeDef = TypedDict(
     "ListProtectionsResponseTypeDef",
-    {"Protections": List[ProtectionTypeDef], "NextToken": str},
+    {"Protections": List["ProtectionTypeDef"], "NextToken": str},
     total=False,
 )
 
